% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chat-helpers.R
\name{init_chat}
\alias{init_chat}
\title{Create an \pkg{ellmer} Chat object for the chat-bot}
\usage{
init_chat(
  system_prompt = getOption("shidashi.chat_system_prompt", NULL),
  provider = getOption("shidashi.chat_provider", "anthropic"),
  base_url = getOption("shidashi.chat_base_url", NULL)
)
}
\arguments{
\item{system_prompt}{character; the system prompt.  Defaults to
\code{getOption("shidashi.chat_system_prompt")}.}

\item{provider}{character; provider name or provider name with models.
Defaults to \code{getOption("shidashi.chat_provider", "anthropic")}.}

\item{base_url}{character or \code{NULL}; base URL for
API-compatible providers.}
}
\value{
An \code{ellmer::Chat} R6 object (tools not yet bound).
}
\description{
Factory function that creates an \code{ellmer::Chat} object based on
the configured provider.  Reads from
\code{options(shidashi.chat_provider)}, \code{shidashi.chat_model},
and \code{shidashi.chat_base_url}. These arguments are passed to
\code{\link[ellmer]{chat}}.
}
\keyword{internal}
